@@ -75,16 +75,15 @@ def _resolve_template(template_values, variables, conf):
 
     return template_values
 
-
 def helm_render(
     templates_dir,
     group,
     template,
     values,
+    generated_dir,
     values_files="",
     enabled_resource_validation=True,
 ):
-    generated_dir = D_PATH / "generated"
     click.echo(f"Generating {values['name']}.yaml")
     with _resolve_values(values) as resolved_str:
         results = run_cmd(
@@ -250,11 +249,11 @@ def render_from_local(templates_dir, services_yaml, input_yaml, services=None):
                     templates_dir,
                     values_files=f"{resolved_str}",
                     enabled_resource_validation=resource_limits,
+                    generated_dir=generated,
                     **helm_info,
                 )
             except Exception as e:
                 click.secho(f"Unable to render template for {resource}: {e}")
-
     configs.save(D_PATH / "configuration" / f"{CLUSTER_NAME}.yaml")
 
 
@@ -279,15 +278,15 @@ def _resolve_remote(remote_path):
 
     run_cmd(
         f"wget {remote_services_yaml} -O {local_directory / 'services.yaml'}",
-        silent=True
-    )
-    assert (local_directory / 'services.yaml').is_file(), (
-        f"Unable to download version {remote_path}"
+        silent=True,
     )
+    assert (
+        local_directory / "services.yaml"
+    ).is_file(), f"Unable to download version {remote_path}"
     run_cmd(
         f"wget {remote_templates_path} -O - | "
         f"tar -xz -C {local_directory / 'templates'}",
-        silent=True
+        silent=True,
     )
     return (local_directory / "services.yaml", local_directory / "templates")
 
@@ -296,9 +295,7 @@ def _resolve_remote(remote_path):
 @click.pass_context
 @click.argument("services", required=False, nargs=-1)
 @click.option("--local", is_flag=True, help="Use local services yaml and templates")
-@click.option(
-    "--no-clean", is_flag=True, help="Keep the remote templates directory",
-)
+@click.option("--no-clean", is_flag=True, help="Keep the remote templates directory")
 def render(
     ctx,
     services=None,
@@ -346,7 +343,7 @@ def render(
         input_yaml.flush()
         try:
             render_from_local(
-                templates_dir, services_yaml, input_yaml.name, services=services,
+                templates_dir, services_yaml, input_yaml.name, services=services
             )
             cluster_manager.edit_cluster_config(changes=old_conf)
             cluster_manager.save()
