@@ -1,7 +1,6 @@
 import click
 import json
 from OpenSSL import crypto
-from onelogin.saml2.idp_metadata_parser import OneLogin_Saml2_IdPMetadataParser
 from click import prompt, secho
 
 from indico_install.utils import run_cmd
@@ -23,7 +22,6 @@ except Exception:
         """Not available"""
         pass
 
-
 @click.group("infra")
 @click.pass_context
 def infra(ctx):
@@ -102,109 +100,116 @@ def generate_saml_cert(ctx, host=None):
     )
     ctx.invoke(restart, services=["noct"], contains=False, wait="2m")
 
-
-@infra.command("generate-saml-settings")
-@click.pass_context
-@click.argument("host", required=True, type=str)
-@click.argument("metadata_url", required=False, type=str)
-@click.option(
-    "-f",
-    "--custom-saml",
-    help="Optional path to a saml settings.json file; if specified, will upload the given file as a noct secret",
-)
-@click.option(
-    "-a",
-    "--advanced-settings",
-    help="Optional path to a saml advanced_settings.json file; if specified, will upload the given file as a noct secret",
-)
-def generate_saml(
-    ctx, host=None, metadata_url=None, custom_saml=None, advanced_settings=None
-):
-    """
-    Generate and inject SAML settings from Azure AD Saml2
-    Before running, complete the following steps:
-    1. Register the indico platform as an app registration in Azure AD
-    2. Add https://<indico IPA hostname>/auth/users/saml/acs" to the web redirection url whitelist
-
-    HOST is the URL of the indico platform
-    METADATA_URL is the federation metadata URL
-
-    Example usage:
-    indico infra generate-saml app.indico.io https://login.microsoftonline.com/12346-78910-11121314/federationmetadata/2007-06/federationmetadata.xml
-
-    Alternatively, inject a custom settings.json file:
-    indico infra generate-saml -f custom-settings.json
-
-    An 'advanced_settings.json' file can be added with:
-    indico infra generate-saml -f custom-settings.json -a advanced_settings.json
-
-    See here for more details: https://github.com/onelogin/python3-saml
-
-    """
-    settings_secret_name = "indico-sso-settings"
-    if run_cmd(f"kubectl get secrets | grep {settings_secret_name}", silent=True):
-        del_secret = prompt(
-            f"Secret named '{settings_secret_name}' already exists; remove and create a new secret?",
-            type=bool,
-            default=False,
-        )
-        if del_secret:
-            run_cmd(f"kubectl delete secret {settings_secret_name}")
-        else:
-            return
-    # load advanced_settings json if it exists
-    adv_settings_content = ""
-    if advanced_settings:
-        with open(advanced_settings) as settings_file:
-            adv_settings = json.load(settings_file)
-        adv_settings_content = json.dumps(adv_settings, indent=4)
-    advanced_secret = (
-        f"--from-literal=advanced_settings.json='{adv_settings_content}'"
-        if adv_settings_content
-        else ""
+try:
+    from onelogin.saml2.idp_metadata_parser import OneLogin_Saml2_IdPMetadataParser
+except ModuleNotFoundError:
+    @infra.command("generate-saml-settings")
+    def generate_saml_cert():
+        """Not available"""
+        secho("The generate-saml-settings command is not available. Please install required packages (i.e., 'sudo apt-get install libxml2-dev libxmlsec1-dev')  and then 'pip3 install indico-install[saml]'", fg="red")
+else:
+    @infra.command("generate-saml-settings")
+    @click.pass_context
+    @click.argument("host", required=True, type=str)
+    @click.argument("metadata_url", required=False, type=str)
+    @click.option(
+        "-f",
+        "--custom-saml",
+        help="Optional path to a saml settings.json file; if specified, will upload the given file as a noct secret",
     )
-    if custom_saml:
-        with open(custom_saml) as settings_file:
-            settings = json.load(settings_file)
-        settings_content = json.dumps(settings, indent=4)
+    @click.option(
+        "-a",
+        "--advanced-settings",
+        help="Optional path to a saml advanced_settings.json file; if specified, will upload the given file as a noct secret",
+    )
+    def generate_saml(
+        ctx, host=None, metadata_url=None, custom_saml=None, advanced_settings=None
+    ):
+        """
+        Generate and inject SAML settings from Azure AD Saml2
+        Before running, complete the following steps:
+        1. Register the indico platform as an app registration in Azure AD
+        2. Add https://<indico IPA hostname>/auth/users/saml/acs" to the web redirection url whitelist
+
+        HOST is the URL of the indico platform
+        METADATA_URL is the federation metadata URL
+
+        Example usage:
+        indico infra generate-saml app.indico.io https://login.microsoftonline.com/12346-78910-11121314/federationmetadata/2007-06/federationmetadata.xml
+
+        Alternatively, inject a custom settings.json file:
+        indico infra generate-saml -f custom-settings.json
+
+        An 'advanced_settings.json' file can be added with:
+        indico infra generate-saml -f custom-settings.json -a advanced_settings.json
+
+        See here for more details: https://github.com/onelogin/python3-saml
+
+        """
+        settings_secret_name = "indico-sso-settings"
+        if run_cmd(f"kubectl get secrets | grep {settings_secret_name}", silent=True):
+            del_secret = prompt(
+                f"Secret named '{settings_secret_name}' already exists; remove and create a new secret?",
+                type=bool,
+                default=False,
+            )
+            if del_secret:
+                run_cmd(f"kubectl delete secret {settings_secret_name}")
+            else:
+                return
+        # load advanced_settings json if it exists
+        adv_settings_content = ""
+        if advanced_settings:
+            with open(advanced_settings) as settings_file:
+                adv_settings = json.load(settings_file)
+            adv_settings_content = json.dumps(adv_settings, indent=4)
+        advanced_secret = (
+            f"--from-literal=advanced_settings.json='{adv_settings_content}'"
+            if adv_settings_content
+            else ""
+        )
+        if custom_saml:
+            with open(custom_saml) as settings_file:
+                settings = json.load(settings_file)
+            settings_content = json.dumps(settings, indent=4)
+            run_cmd(
+                f"""kubectl create secret generic {settings_secret_name} --from-literal=settings.json='{settings_content}' """
+                + f"{advanced_secret}",
+                silent=True,
+            )
+            ctx.invoke(restart, services=["noct"], contains=False, wait="2m")
+            return
+
+        # not using custom settings
+        if not (host and metadata_url):
+            click.secho(
+                "Please provide a host and metadata url if not using a custom settings.json file",
+                fg="red",
+            )
+            return
+        idp_info = OneLogin_Saml2_IdPMetadataParser.parse_remote(metadata_url)
+        jacs = {
+            "url": "https://" + host + "/auth/users/saml/acs",
+            "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
+        }
+        jsls = {
+            "url": "https://" + host + "/auth/users/saml/sls",
+            "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
+        }
+        jsp = {
+            "entityId": "https://" + host + "/auth/users/saml/metadata",
+            "assertionConsumerService": jacs,
+            "singleLogoutService": jsls,
+            "NameIDFormat": "urn:oasis:names:tc:SAML:1.1:nameid-format:emailAddress",
+        }
+        stg = {"strict": "true", "debug": "true", "sp": jsp, "idp": idp_info["idp"]}
+        settings_content = json.dumps(stg, indent=4)
         run_cmd(
             f"""kubectl create secret generic {settings_secret_name} --from-literal=settings.json='{settings_content}' """
             + f"{advanced_secret}",
             silent=True,
         )
         ctx.invoke(restart, services=["noct"], contains=False, wait="2m")
-        return
-
-    # not using custom settings
-    if not (host and metadata_url):
-        click.secho(
-            "Please provide a host and metadata url if not using a custom settings.json file",
-            fg="red",
-        )
-        return
-    idp_info = OneLogin_Saml2_IdPMetadataParser.parse_remote(metadata_url)
-    jacs = {
-        "url": "https://" + host + "/auth/users/saml/acs",
-        "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST",
-    }
-    jsls = {
-        "url": "https://" + host + "/auth/users/saml/sls",
-        "binding": "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect",
-    }
-    jsp = {
-        "entityId": "https://" + host + "/auth/users/saml/metadata",
-        "assertionConsumerService": jacs,
-        "singleLogoutService": jsls,
-        "NameIDFormat": "urn:oasis:names:tc:SAML:1.1:nameid-format:emailAddress",
-    }
-    stg = {"strict": "true", "debug": "true", "sp": jsp, "idp": idp_info["idp"]}
-    settings_content = json.dumps(stg, indent=4)
-    run_cmd(
-        f"""kubectl create secret generic {settings_secret_name} --from-literal=settings.json='{settings_content}' """
-        + f"{advanced_secret}",
-        silent=True,
-    )
-    ctx.invoke(restart, services=["noct"], contains=False, wait="2m")
 
 
 @infra.command("download-apidata")
