@@ -4,7 +4,7 @@ from indico_install.utils import run_cmd
 FILE_SHARE_SECRET_NAME = "azure-storage-key"
 
 
-def create(deployment_root, conf):
+def create(conf):
     storage_acct_name = conf["cluster"]["storage_acct"]
     storage_acct_key = conf["cluster"]["storage_acct_key"]
     run_cmd(
