@@ -1,6 +1,7 @@
 import click
 from indico_install.kube.svc.restart import restart
-from indico_install.kube.svc.scale import scale, delete
+from indico_install.kube.svc.scale import scale, delete, enable
+from indico_install.kube.svc.manage import put_resource
 from indico_install.cluster_manager import ClusterManager
 
 
@@ -12,5 +13,5 @@ def svc(ctx):
     ctx.obj["TRACKER"] = ClusterManager()
 
 
-for command in [restart, scale, delete]:
+for command in [restart, scale, delete, enable, put_resource]:
     svc.add_command(command)
